@@ -12,3 +12,7 @@ function expandCollapseSection(nodeId) {
     /* In Trac 0.11 we must handle sections explicitly */
     $('#'+nodeId).toggleClass('collapsed');
 }
+
+function _(str) {
+	return str;
+}
